/***************************************************************************
 *   Copyright (C) 2004 by Rick L. Vinyard, Jr.                            *
 *   rvinyard@cs.nmsu.edu                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Lesser General Public License as        *
 *   published by the Free Software Foundation version 2.1.                *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU Lesser General Public      *
 *   License along with this library; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA              *
 ***************************************************************************/
#ifndef PAPYRUSFACE_H
#define PAPYRUSFACE_H

#include <papyrus/group.h>

namespace Papyrus
  {

  /**
   * Why is there a Face primitive in this library? For testing of course; like the
   * teapot in OpenGL.
   *
   * @author Rick L Vinyard Jr <rvinyard@cs.nmsu.edu>
   */
  class Face : public Drawable
    {
    public:
      typedef enum TYPE {
        SMILEY,
      } TYPE;

      typedef PapyrusSmartPointer<Face> pointer;

      Face(double size=20.0, TYPE type = SMILEY);

      static Face::pointer create(double size=20.0, TYPE type = SMILEY);

      virtual ~Face();

      virtual void draw( Cairo::RefPtr<Cairo::Context> cairo );

      TYPE type();
      void set_type(TYPE type);

      double size();
      void set_size(double size);

      void set_size_type(double size, TYPE type);

      PAPYRUS_CLASS_NAME("Face");

      PAPYRUS_CLONE_METHOD( Face );

    protected:
      TYPE m_type;
      double m_size;

    };

  }

#endif
