/***************************************************************************
*   Copyright (C) 2004 by Rick L. Vinyard, Jr.                            *
*   rvinyard@cs.nmsu.edu                                                  *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU Lesser General Public License as        *
*   published by the Free Software Foundation version 2.1.                *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU Lesser General Public      *
*   License along with this library; if not, write to the                 *
*   Free Software Foundation, Inc.,                                       *
*   51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA              *
***************************************************************************/
#ifndef PAPYRUSGTKLINESTYLEWIDGET_H
#define PAPYRUSGTKLINESTYLEWIDGET_H

#include <gtkmm/table.h>

#include <papyrus/linestyle.h>
#include <papyrus/polyline.h>
#include <papyrusmm/linejoinbuttonbox.h>
#include <papyrusmm/linecapbuttonbox.h>
#include <papyrusmm/viewport.h>

namespace PapyrusGtk {

/**
	@author Rick L Vinyard Jr <rvinyard@cs.nmsu.edu>
*/
class LineStyleWidget : public Gtk::Table
{
public:
    LineStyleWidget(bool use_preview=true);

    ~LineStyleWidget();

		const Papyrus::LineStyle& get_line_style() const;

    bool use_preview();
    void set_use_preview(bool use=true);

	protected:
    Gtk::Expander* m_expander;
    PapyrusGtk::Viewport* m_viewport;
    Papyrus::Polyline::pointer m_line;

		Gtk::ColorButton m_color_button;
		Gtk::Adjustment m_width_adjustment;
		Gtk::SpinButton m_width_entry;
		Gtk::Adjustment m_miter_limit_adjustment;
		Gtk::SpinButton m_miter_limit_entry;
		PapyrusGtk::LineJoinButtonBox m_line_join_buttonbox;
		PapyrusGtk::LineCapButtonBox m_line_cap_buttonbox;

		Papyrus::LineStyle m_line_style;

		void on_color_changed();
		void on_width_changed();
    void on_line_join_changed( Cairo::LineJoin );
    void on_line_cap_changed( Cairo::LineCap );

};

}

#endif
