/* Scaler
 *
 */

#include "gtkmm.h"

#include <papyrus.h>
#include <papyrusmm/viewport.h>

class Example_Scaler : public Gtk::Window
{
  public:
    Example_Scaler();
    virtual ~Example_Scaler();

  protected:
  //Member widgets:
    PapyrusGtk::Viewport m_Viewport;
    Papyrus::Scaler::pointer m_Scaler;
    Papyrus::Boxed::pointer m_boxed;

    Gtk::CheckButton m_translate_x_button, m_translate_y_button;
    Gtk::Adjustment m_grid_x_adj, m_grid_y_adj;
    Gtk::SpinButton m_grid_x, m_grid_y;
    Gtk::ToggleButton m_side_buttons[4];

  void on_translate_x_toggled();
  void on_translate_y_toggled();
  void on_grid_x_changed();
  void on_grid_y_changed();
  void on_button_toggled( int which );
};

//Called by DemoWindow;
Gtk::Window* do_Scaler()
{
  return new Example_Scaler();
}

Example_Scaler::Example_Scaler():
  m_translate_x_button("Translate X"),
  m_translate_y_button("Translate Y"),
  m_grid_x_adj( 0.0, 0.0, 500.0, 10.0, 50.0 ),
  m_grid_y_adj( 0.0, 0.0, 500.0, 10.0, 50.0 ),
  m_grid_x( m_grid_x_adj ),
  m_grid_y( m_grid_y_adj )
{
  Gtk::HBox* hbox;
  Gtk::VBox* vbox;

  set_title("Scaler Example");

  m_boxed = Papyrus::Boxed::create( );
  m_boxed->get_box()->set_fill( Cairo::SolidPattern::create_rgba(1.0, 0.85, 1.0, 0.9) );
  m_boxed->get_box()->set_outline( Cairo::SolidPattern::create_rgba(1.0, 0.0, 1.0, 0.9) );

  m_Scaler = Papyrus::Scaler::create( m_Viewport.canvas(), m_boxed );
  m_Viewport.add_controller( m_Scaler );

  m_Viewport.set_size_request( 300, 200 );

  // Create some shapes to add to the group
  Papyrus::Rectangle::pointer rectangle = Papyrus::example_rectangle( );
  Papyrus::Circle::pointer circle = Papyrus::example_circle( );
  Papyrus::Arc::pointer arc = Papyrus::example_arc( );

  // Add the shapes to the group
  m_Viewport.canvas()->add( rectangle );
  m_Viewport.canvas()->add( circle );
  m_Viewport.canvas()->add( arc );
  m_Viewport.canvas()->add( m_boxed );

  // Translate the shapes so they don't necessarily overlap
  rectangle->set_xywh(0, -60, 50, 30);
  circle->set_translate(40, 20);
  circle->set_radius(25);
  arc->set_translate(0, 20);

  vbox = Gtk::manage( new Gtk::VBox() );
  vbox->pack_start( m_Viewport );
  vbox->pack_start( *Gtk::manage( new Gtk::HSeparator() ) );
//   vbox->pack_start( m_translate_x_button );
//   vbox->pack_start( m_translate_y_button );
//   m_translate_x_button.set_active(true);
//   m_translate_y_button.set_active(true);

//   hbox = Gtk::manage( new Gtk::HBox() );
//   hbox->pack_start( *Gtk::manage( new Gtk::Label("Grid X size") ) );
//   hbox->pack_start( m_grid_x );
//   vbox->pack_start( *hbox );

//   hbox = Gtk::manage( new Gtk::HBox() );
//   hbox->pack_start( *Gtk::manage( new Gtk::Label("Grid Y size") ) );
//   hbox->pack_start( m_grid_y );
//   vbox->pack_start( *hbox );

  Gtk::Table* table;

  table = Gtk::manage( new Gtk::Table() );
  m_side_buttons[0].set_label("Top");
  m_side_buttons[1].set_label("Right");
  m_side_buttons[2].set_label("Bottom");
  m_side_buttons[3].set_label("Left");
  table->attach( m_side_buttons[0], 1, 2, 0, 1 );
  table->attach( m_side_buttons[1], 2, 3, 1, 2 );
  table->attach( m_side_buttons[2], 1, 2, 2, 3 );
  table->attach( m_side_buttons[3], 0, 1, 1, 2 );
  for ( int i=0; i < 4; i++ )
    m_side_buttons[i].signal_toggled().connect(sigc::bind(sigc::mem_fun(*this, &Example_Scaler::on_button_toggled), i ) );

  vbox->pack_start( *table );

  this->add( *vbox );

  m_translate_x_button.signal_toggled().connect( sigc::mem_fun(*this, &Example_Scaler::on_translate_x_toggled) );
  m_translate_y_button.signal_toggled().connect( sigc::mem_fun(*this, &Example_Scaler::on_translate_y_toggled) );
  m_grid_x.signal_value_changed().connect( sigc::mem_fun(*this, &Example_Scaler::on_grid_x_changed) );
  m_grid_y.signal_value_changed().connect( sigc::mem_fun(*this, &Example_Scaler::on_grid_y_changed) );

  show_all();
}

Example_Scaler::~Example_Scaler()
{
}

void Example_Scaler::on_translate_x_toggled()
{
/*  if ( m_translate_x_button.get_active() )
    m_Scaler->enable_sides( Papyrus::TRANSLATE_X );
  else
    m_Scaler->disable_sides( Papyrus::TRANSLATE_X );*/
}

void Example_Scaler::on_translate_y_toggled()
{
/*  if ( m_translate_y_button.get_active() )
    m_Scaler->enable_sides( Papyrus::TRANSLATE_Y );
  else
    m_Scaler->disable_sides( Papyrus::TRANSLATE_Y );*/
}

void Example_Scaler::on_grid_x_changed()
{
//   m_Scaler->set_grid_x( m_grid_x.get_value() );
}

void Example_Scaler::on_grid_y_changed()
{
//   m_Scaler->set_grid_y( m_grid_y.get_value() );
}

void Example_Scaler::on_button_toggled( int which )
{
  Papyrus::Side side;
  switch (which) {
    case 0:
      side = Papyrus::TOP;
      break;
    case 1:
      side = Papyrus::RIGHT;
      break;
    case 2:
      side = Papyrus::BOTTOM;
      break;
    case 3:
      side = Papyrus::LEFT;
      break;
  }

  if ( m_side_buttons[which].get_active() )
    m_Scaler->enable_sides( side );
  else
    m_Scaler->disable_sides( side );

}
